@@ -13,6 +13,12 @@ pub struct Unset {
     auth: bool,
     #[structopt(short, long, help = "The TTL for the nodes cache file in seconds")]
     cache_ttl: bool,
+    #[structopt(
+        short,
+        long,
+        help = "A list of labels that should be shown. If none is set all labels will be shown"
+    )]
+    label_whitelist: bool,
 }
 
 impl Unset {
@@ -35,6 +41,10 @@ impl Unset {
             config.auth = None;
         }
 
+        if self.label_whitelist {
+            config.label_whitelist = None;
+        }
+
         config.write()?;
 
         Ok(())
